pub enum JsNumberType {
Integer(i64),
Float(f64),
NaN,
PositiveInfinity,
NegativeInfinity,
}Expand description
JavaScript number type.
JavaScript numbers can be represented as either integers or floats. The engine uses integers when possible for better performance.
Examples
use just::runner::ds::value::JsNumberType;
let int = JsNumberType::Integer(42);
let float = JsNumberType::Float(3.14);
let infinity = JsNumberType::Float(f64::INFINITY);Variants