pub struct SimpleFunctionObject { /* private fields */ }Expand description
Simple function object that stores function metadata for evaluation. Instead of storing AST data directly, we store references to the source AST.
Implementations
Sourceimpl SimpleFunctionObject
impl SimpleFunctionObject
pub fn new( body_ptr: *const FunctionBodyData, params_ptr: *const Vec<PatternType>, environment: JsLexEnvironmentType, ) -> Self
Sourcepub fn call_with_this(
&self,
this_value: JsValue,
args: Vec<JsValue>,
ctx: &mut EvalContext,
) -> ValueResult
pub fn call_with_this( &self, this_value: JsValue, args: Vec<JsValue>, ctx: &mut EvalContext, ) -> ValueResult
Call this function with the given this value and arguments. Safety: The AST pointers must still be valid.