Module types

Module types 

Core types for the evaluation engine.

Structs

Completion
Completion record. Every statement evaluation returns a completion record.
EnvironmentRef
Reference to an environment record.
Reference
Reference type. Used for identifier resolution and property access.

Enums

CompletionType
Completion record type. Represents the result of evaluating a statement or expression.
ReferenceBase
Reference base type. A reference can be based on an object, environment record, or be unresolvable.

Type Aliases

EvalResult
Result type for evaluation operations.
ReferenceResult
Result type for reference-returning operations.
ValueResult
Result type for value-returning operations.