CorePluginResolver

Struct CorePluginResolver 

pub struct CorePluginResolver { /* private fields */ }
Wraps a BuiltInRegistry as a PluginResolver.

When the super-global scope queries for a name like "Math", this resolver checks the registry and materializes a proxy object whose method calls are dispatched back to the registry.

Implementations