Module resolver

Module resolver 

Plugin resolver trait for lazy, dynamic resolution of super-global objects.

Plugins implement PluginResolver to provide objects (like Math, console) that are available in the super-global scope. Objects are resolved lazily — only when JS code actually references them.

Traits

PluginResolver
A plugin resolver that can dynamically provide named objects and their methods.