pub struct CorePluginResolver { /* private fields */ }Expand description
Wraps a BuiltInRegistry as a PluginResolver.
When the super-global scope queries for a name like "Math",
this resolver checks the registry and materializes a proxy object
whose method calls are dispatched back to the registry.
Implementations
Sourceimpl CorePluginResolver
impl CorePluginResolver
pub fn new(registry: BuiltInRegistry) -> Self
pub fn registry(&self) -> &BuiltInRegistry